filter_vif: Filters out equations with high multicollinearity
Description
This function takes a dataframe with several models and
calculates the maximum Variance Inflation Factor (VIF) for a given
model. And either filters out the ones with high collinearity or it
flags them accordingly